==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/TOBUDGETENTITYOPTIONS.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBUDGETENTITYID" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBUDGETENTITYGROUPID" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "tobudgetentityid",
    "tobudgetentitygroupid"
})
@XmlRootElement(name = "TOBUDGETENTITYOPTIONS")
public class TOBUDGETENTITYOPTIONS {

    @XmlElement(name = "TOBUDGETENTITYID")
    protected BUDGETENTITY_Type tobudgetentityid;
    @XmlElement(name = "TOBUDGETENTITYGROUPID")
    protected BUDGETENTITYGROUP_Type tobudgetentitygroupid;

    /**
     * Obtient la valeur de la propriété tobudgetentityid.
     * 
     * @return
     *     possible object is
     *     {@link BUDGETENTITY_Type }
     *     
     */
    public BUDGETENTITY_Type getTOBUDGETENTITYID() {
        return tobudgetentityid;
    }

    /**
     * Définit la valeur de la propriété tobudgetentityid.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGETENTITY_Type }
     *     
     */
    public void setTOBUDGETENTITYID(BUDGETENTITY_Type value) {
        this.tobudgetentityid = value;
    }

    /**
     * Obtient la valeur de la propriété tobudgetentitygroupid.
     * 
     * @return
     *     possible object is
     *     {@link BUDGETENTITYGROUP_Type }
     *     
     */
    public BUDGETENTITYGROUP_Type getTOBUDGETENTITYGROUPID() {
        return tobudgetentitygroupid;
    }

    /**
     * Définit la valeur de la propriété tobudgetentitygroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGETENTITYGROUP_Type }
     *     
     */
    public void setTOBUDGETENTITYGROUPID(BUDGETENTITYGROUP_Type value) {
        this.tobudgetentitygroupid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/TOBUDGETENTITYOPTIONS.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBUDGETENTITYID" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBUDGETENTITYGROUPID" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "tobudgetentityid",
    "tobudgetentitygroupid"
})
@XmlRootElement(name = "TOBUDGETENTITYOPTIONS")
public class TOBUDGETENTITYOPTIONS {

    @XmlElement(name = "TOBUDGETENTITYID")
    protected BUDGETENTITY_Type tobudgetentityid;
    @XmlElement(name = "TOBUDGETENTITYGROUPID")
    protected BUDGETENTITYGROUP_Type tobudgetentitygroupid;

    /**
     * Gets the value of the tobudgetentityid property.
     * 
     * @return
     *     possible object is
     *     {@link BUDGETENTITY_Type }
     *     
     */
    public BUDGETENTITY_Type getTOBUDGETENTITYID() {
        return tobudgetentityid;
    }

    /**
     * Sets the value of the tobudgetentityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGETENTITY_Type }
     *     
     */
    public void setTOBUDGETENTITYID(BUDGETENTITY_Type value) {
        this.tobudgetentityid = value;
    }

    /**
     * Gets the value of the tobudgetentitygroupid property.
     * 
     * @return
     *     possible object is
     *     {@link BUDGETENTITYGROUP_Type }
     *     
     */
    public BUDGETENTITYGROUP_Type getTOBUDGETENTITYGROUPID() {
        return tobudgetentitygroupid;
    }

    /**
     * Sets the value of the tobudgetentitygroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BUDGETENTITYGROUP_Type }
     *     
     */
    public void setTOBUDGETENTITYGROUPID(BUDGETENTITYGROUP_Type value) {
        this.tobudgetentitygroupid = value;
    }

}
